@@ -5,10 +5,10 @@ from .searchresult import SearchResult
 class SearchResponse:
     """Represents a Bing Response (not a search result response)
     
-    ```{caution}
-    You must not manually initialize this!
-    ```"""
-    def __init__(self, data):
+    .. warning::
+        You must not manually initialize this!
+    """
+    def __init__(self, data: dict):
         self.data = data
         self.resulNum = 0
 
@@ -40,7 +40,15 @@ class SearchResponse:
         return (SearchResult(self.data['webPages']['value'][0]), SearchResult(self.data['webPages']['value'][1]), SearchResult(self.data['webPages']['value'][2]))
     
     def getMany(self, amount: int, *, start: int=0) -> Tuple[SearchResult]:
-        """Returns as many :class:`asyncbing.SearchResult` as you want as the max defined by the int passed into the function. has an optional ``start`` kwarg. Defaults to 0."""
+        """Returns as many :class:`asyncbing.SearchResult` as you want as the max defined by the int passed into the function. Has an optional ``start`` kwarg. Defaults to 0.\n
+        Will not increase the amount of items for getNext()"""
         if not len(self.data['webPages']['value']) >= amount:
             raise NotEnoughResults("There weren't enough search results to give a BingSearchResult for the specified amount.")
         return ([SearchResult(self.data['webPages']['value'][x]) for x in range(start, amount)])
+
+    def getNext(self) -> SearchResult:
+        """Gets the next result and returns a :class:`asyncbing.SearchResult`"""
+        if self.resulNum >= len(self.data['webPages']['value']):
+            raise NotEnoughResults("There aren't any more results to give a BingSearchResult.")
+        self.resulNum += 1
+        return SearchResult(self.data['webPages']['value'][self.resulNum])
\ No newline at end of file
